@@ -1,3 +1,3 @@
 suppressMessages(library(lubridate))
 suppressMessages(library(dplyr))
-suppressMessages(library(lintr))
+# suppressMessages(library(lintr))
